@@ -1,19 +1,22 @@
 from db.db_op import userDao
 
+from model2.common_utils import resp_result
+
+
 class service():
     def _api_find(self, **params):
         if params:
             for i in params:
-                print("find params===>", i)
+                print("find params===>key={0},value={1}".format(i, params[i]))
 
         user = userDao()
-        return user.find()
+        return resp_result(data=user.find())
 
     def _api_add(self, **params):
         if params:
             for i in params:
-                print("find params===>", i)
+                print("find params===>key={0},value={1}".format(i, params[i]))
 
         user = userDao()
         user.add()
-        return True
\ No newline at end of file
+        return resp_result()
\ No newline at end of file
